[brasero] Fix #596532 - String fixes



commit e35dbe4dba07322327667f94651e494d337dc7ec
Author: Philippe Rouquier <bonfire-app wanadoo fr>
Date:   Mon Oct 5 20:37:05 2009 +0200

    Fix #596532 -  String fixes
    Patch by Philip Withnall <bugzilla tecnocode co uk>
    Miscellaneous string fixes, such as capitalisation and spelling fixes, as well as some rewordings to make things sound better

 data/brasero.schemas.in                    |   16 ++++++++--------
 libbrasero-burn/brasero-blank-dialog.c     |    2 +-
 libbrasero-burn/brasero-burn-dialog.c      |    4 ++--
 libbrasero-burn/brasero-burn-options.c     |    6 +++---
 libbrasero-burn/brasero-burn.c             |    4 ++--
 libbrasero-burn/brasero-caps-burn.c        |    4 ++--
 libbrasero-burn/brasero-dest-selection.c   |    2 +-
 libbrasero-burn/brasero-drive-properties.c |    4 ++--
 libbrasero-burn/brasero-status-dialog.c    |   10 +++++-----
 libbrasero-burn/brasero-sum-dialog.c       |   12 ++++++------
 libbrasero-burn/brasero-video-options.c    |    4 ++--
 libbrasero-burn/burn-basics.c              |    2 +-
 libbrasero-burn/burn-job.c                 |    6 +++---
 libbrasero-burn/burn-mkisofs-base.c        |    2 +-
 libbrasero-media/brasero-media.c           |    2 +-
 libbrasero-media/brasero-medium.c          |    4 ++--
 libbrasero-utils/brasero-metadata.c        |    2 +-
 nautilus/nautilus-burn-bar.c               |    2 +-
 nautilus/nautilus-burn-extension.c         |   12 ++++++------
 plugins/cdrdao/burn-cdrdao-common.h        |    2 +-
 plugins/cdrdao/burn-cdrdao.c               |    2 +-
 plugins/cdrdao/burn-toc2cue.c              |    2 +-
 plugins/cdrkit/burn-cdrkit.h               |    2 +-
 plugins/cdrkit/burn-genisoimage.c          |    2 +-
 plugins/cdrkit/burn-readom.c               |    4 ++--
 plugins/cdrkit/burn-wodim.c                |   12 ++++++------
 plugins/cdrtools/burn-cdrecord.c           |   18 +++++++++---------
 plugins/cdrtools/burn-cdrtools.h           |    2 +-
 plugins/cdrtools/burn-mkisofs.c            |    4 ++--
 plugins/cdrtools/burn-readcd.c             |    4 ++--
 plugins/checksum/burn-checksum-files.c     |    2 +-
 plugins/checksum/burn-checksum-image.c     |    2 +-
 plugins/dvdcss/burn-dvdcss.c               |    6 +++---
 plugins/growisofs/burn-growisofs-common.h  |    2 +-
 plugins/growisofs/burn-growisofs.c         |    2 +-
 plugins/libburnia/burn-libburn-common.c    |    2 +-
 plugins/libburnia/burn-libburn.c           |   12 ++++++------
 plugins/libburnia/burn-libburnia.h         |    2 +-
 plugins/libburnia/burn-libisofs.c          |   16 ++++++++--------
 plugins/local-track/burn-local-image.c     |    2 +-
 plugins/local-track/burn-uri.c             |    2 +-
 plugins/transcode/burn-normalize.c         |    2 +-
 plugins/transcode/burn-transcode.c         |    2 +-
 plugins/transcode/burn-vob.c               |    2 +-
 src/brasero-app.c                          |    2 +-
 src/brasero-audio-disc.c                   |   12 ++++++------
 src/brasero-data-disc.c                    |   14 +++++++-------
 src/brasero-eject-dialog.c                 |    2 +-
 src/brasero-layout.c                       |    2 +-
 src/brasero-multi-song-props.c             |    6 +++---
 src/brasero-playlist.c                     |    2 +-
 src/brasero-project-manager.c              |    2 +-
 src/brasero-project-type-chooser.c         |    4 ++--
 src/brasero-project.c                      |   26 +++++++++++++-------------
 src/brasero-rename.c                       |   20 ++++++++++----------
 src/brasero-song-properties.c              |    6 +++---
 src/brasero-split-dialog.c                 |    2 +-
 src/brasero-video-disc.c                   |    4 ++--
 src/main.c                                 |   14 +++++++-------
 59 files changed, 164 insertions(+), 164 deletions(-)
---
diff --git a/data/brasero.schemas.in b/data/brasero.schemas.in
index 55452f9..20d25ab 100644
--- a/data/brasero.schemas.in
+++ b/data/brasero.schemas.in
@@ -37,8 +37,8 @@
 	<type>bool</type>
 	<default>false</default>
 	<locale name="C">
-	  <short>Enable "-immed" flag with cdrecord</short>
-	  <long>Whether to use "-immed" flag with cdrecord. Use with caution (set to true) as it's only a workaround for some drives/setups.</long>
+	  <short>Enable the "-immed" flag with cdrecord</short>
+	  <long>Whether to use the "-immed" flag with cdrecord. Use with caution (set to true) as it's only a workaround for some drives/setups.</long>
 	</locale>
        </schema>
 
@@ -49,8 +49,8 @@
  	<type>bool</type>
  	<default>false</default>
  	<locale name="C">
- 	<short>Whether to use "-use-the-force-luke=dao" flag with growisofs</short>
- 	<long>Whether to use "-use-the-force-luke=dao" flag with
+ 	<short>Whether to use the "-use-the-force-luke=dao" flag with growisofs</short>
+ 	<long>Whether to use the "-use-the-force-luke=dao" flag with
  	growisofs. Set to false, brasero won't use it; it may be a workaround for some drives/setups.</long>
  	</locale>
  	</schema> 
@@ -62,8 +62,8 @@
 	<type>int</type>
 	<default>0</default>
 	<locale name="C">
-	  <short>Used in conjunction with "-immed" flag with cdrecord</short>
-	  <long>Used in conjunction with "-immed" flag with cdrecord</long>
+	  <short>Used in conjunction with the "-immed" flag with cdrecord</short>
+	  <long>Used in conjunction with the "-immed" flag with cdrecord.</long>
 	</locale>
        </schema>
 
@@ -74,8 +74,8 @@
 	<type>bool</type>
 	<default>false</default>
 	<locale name="C">
-	<short>Whether to use "--driver generic-mmc-raw" flag with cdrdao</short>
-	<long>Whether to use "--driver generic-mmc-raw" flag with
+	<short>Whether to use the "--driver generic-mmc-raw" flag with cdrdao</short>
+	<long>Whether to use the "--driver generic-mmc-raw" flag with
 	cdrdao. Set to True, brasero will use it; it may be a workaround for some drives/setups.</long>
 	</locale>
       </schema> 
diff --git a/libbrasero-burn/brasero-blank-dialog.c b/libbrasero-burn/brasero-blank-dialog.c
index 57d101b..c885a7a 100644
--- a/libbrasero-burn/brasero-blank-dialog.c
+++ b/libbrasero-burn/brasero-blank-dialog.c
@@ -395,7 +395,7 @@ brasero_blank_dialog_init (BraseroBlankDialog *obj)
 					   obj);
 
 	priv->fast = gtk_check_button_new_with_mnemonic (_("_Fast blanking"));
-	gtk_widget_set_tooltip_text (priv->fast, _("Activate fast blanking by opposition to a longer thorough blanking"));
+	gtk_widget_set_tooltip_text (priv->fast, _("Activate fast blanking, as opposed to a longer, thorough blanking"));
 	g_signal_connect (priv->fast,
 			  "clicked",
 			  G_CALLBACK (brasero_blank_dialog_fast_toggled),
diff --git a/libbrasero-burn/brasero-burn-dialog.c b/libbrasero-burn/brasero-burn-dialog.c
index 921374a..a6e277c 100644
--- a/libbrasero-burn/brasero-burn-dialog.c
+++ b/libbrasero-burn/brasero-burn-dialog.c
@@ -914,7 +914,7 @@ brasero_burn_dialog_audio_to_appendable_cb (BraseroBurn *burn,
 	BraseroBurnResult result;
 
 	secondary = g_strdup_printf ("%s\n%s",
-				     _("CD-RW audio discs may not play correctly in older CD players and CD-TEXT won't be written."),
+				     _("CD-RW audio discs may not play correctly in older CD players and CD-Text won't be written."),
 				     _("Do you want to continue anyway?"));
 
 	result = brasero_burn_dialog_loss_warnings_cb (dialog,
@@ -1791,7 +1791,7 @@ brasero_burn_dialog_notify_error (BraseroBurnDialog *dialog,
 		g_error_free (error);
 	}
 	else
-		secondary = g_strdup (_("An unknown error occured."));
+		secondary = g_strdup (_("An unknown error occurred."));
 
 	if (!GTK_WIDGET_VISIBLE (dialog))
 		gtk_widget_show (GTK_WIDGET (dialog));
diff --git a/libbrasero-burn/brasero-burn-options.c b/libbrasero-burn/brasero-burn-options.c
index 68fb8bb..32d2249 100644
--- a/libbrasero-burn/brasero-burn-options.c
+++ b/libbrasero-burn/brasero-burn-options.c
@@ -459,7 +459,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		GtkWidget *message;
 
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
-						      _("Would you like to burn beyond the disc reported capacity?"),
+						      _("Would you like to burn beyond the disc's reported capacity?"),
 						      _("The data size is too large for the disc and you must remove files from the selection otherwise."
 							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
 							"\nNOTE: This option might cause failure."),
@@ -468,7 +468,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		brasero_notify_button_add (BRASERO_NOTIFY (priv->message_output),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Overburn"),
-					   _("Burn beyond the disc reported capacity"),
+					   _("Burn beyond the disc's reported capacity"),
 					   GTK_RESPONSE_OK);
 
 		g_signal_connect (message,
@@ -480,7 +480,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		/* The medium is valid but it's a special case */
 		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
 					    _("The drive that holds the source disc will also be the one used to record."),
-					    _("A new recordable disc will be required once the one currently loaded has been copied."),
+					    _("A new recordable disc will be required once the currently loaded one has been copied."),
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
diff --git a/libbrasero-burn/brasero-burn.c b/libbrasero-burn/brasero-burn.c
index 0c21083..40ad21b 100644
--- a/libbrasero-burn/brasero-burn.c
+++ b/libbrasero-burn/brasero-burn.c
@@ -1116,7 +1116,7 @@ again:
 	}
 
 	if (!priv->dest_locked
-	&&  !brasero_drive_lock (priv->dest, _("Ongoing checksuming operation"), &failure)) {
+	&&  !brasero_drive_lock (priv->dest, _("Ongoing checksumming operation"), &failure)) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
@@ -2753,7 +2753,7 @@ end:
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("An internal error occured"));
+			     _("An internal error occurred"));
 	}
 
 	if (result == BRASERO_BURN_CANCEL) {
diff --git a/libbrasero-burn/brasero-caps-burn.c b/libbrasero-burn/brasero-caps-burn.c
index f4f4b08..9f1ef97 100644
--- a/libbrasero-burn/brasero-caps-burn.c
+++ b/libbrasero-burn/brasero-caps-burn.c
@@ -61,7 +61,7 @@
 		g_set_error (error,						\
 			     BRASERO_BURN_ERROR,				\
 			     BRASERO_BURN_ERROR_GENERAL,			\
-			     _("An internal error occured"));	 		\
+			     _("An internal error occurred"));	 		\
 	BRASERO_BURN_CAPS_NOT_SUPPORTED_LOG (session);				\
 }
 
@@ -676,7 +676,7 @@ brasero_burn_caps_new_task (BraseroBurnCaps *self,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			g_slist_foreach (retval, (GFunc) g_object_unref, NULL);
 			g_slist_free (retval);
 			g_slist_free (list);
diff --git a/libbrasero-burn/brasero-dest-selection.c b/libbrasero-burn/brasero-dest-selection.c
index a4c6fcf..a0c1df7 100644
--- a/libbrasero-burn/brasero-dest-selection.c
+++ b/libbrasero-burn/brasero-dest-selection.c
@@ -638,7 +638,7 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 			 * destination disc a new one (once the source has been
 			 * copied) which is to be inserted in the drive currently
 			 * holding the source disc */
-			label = g_strdup_printf (_("New disc in the burner holding source disc"));
+			label = g_strdup_printf (_("New disc in the burner holding the source disc"));
 			g_free (medium_name);
 
 			brasero_medium_selection_update_used_space (BRASERO_MEDIUM_SELECTION (selection),
diff --git a/libbrasero-burn/brasero-drive-properties.c b/libbrasero-burn/brasero-drive-properties.c
index 4185200..7a138fa 100644
--- a/libbrasero-burn/brasero-drive-properties.c
+++ b/libbrasero-burn/brasero-drive-properties.c
@@ -604,7 +604,7 @@ brasero_drive_properties_set_drive (BraseroDriveProperties *self,
 
 	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			    TEXT_COL, _("Max speed"),
+			    TEXT_COL, _("Maximum speed"),
 			    RATE_COL, rates [0],
 			    -1);
 
@@ -744,7 +744,7 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 					NULL);
 
 	priv->dummy = gtk_check_button_new_with_mnemonic (_("_Simulate before burning"));
-	gtk_widget_set_tooltip_text (priv->dummy, _("Brasero will simulate the burning and if it is successful, go on with actual burning after 10 seconds"));
+	gtk_widget_set_tooltip_text (priv->dummy, _("Brasero will simulate the burning and, if it is successful, go on with actual burning after 10 seconds"));
 	gtk_widget_show (priv->dummy);
 	priv->burnproof = gtk_check_button_new_with_mnemonic (_("Use burn_proof (decrease the risk of failures)"));
 	gtk_widget_show (priv->burnproof);
diff --git a/libbrasero-burn/brasero-status-dialog.c b/libbrasero-burn/brasero-status-dialog.c
index 5020b41..93d7098 100644
--- a/libbrasero-burn/brasero-status-dialog.c
+++ b/libbrasero-burn/brasero-status-dialog.c
@@ -187,7 +187,7 @@ brasero_status_dialog_deep_directory_cb (BraseroTrackDataCfg *project,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
 						  _("The children of this directory will have 7 parent directories."
 						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
-						    "\nNOTE: Such a file hierarchy is known to work on linux."));
+						    "\nNote: Such a file hierarchy is known to work on Linux."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (message), _("_Add File"), GTK_RESPONSE_YES);
@@ -211,7 +211,7 @@ brasero_status_dialog_2G_file_cb (BraseroTrackDataCfg *track,
 
 	gtk_widget_hide (GTK_WIDGET (dialog));
 
-	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"), name);
+	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of the ISO9660 standard to support it?"), name);
 	message = gtk_message_dialog_new (GTK_WINDOW (dialog),
 					  GTK_DIALOG_DESTROY_WITH_PARENT|
 					  GTK_DIALOG_MODAL,
@@ -221,9 +221,9 @@ brasero_status_dialog_2G_file_cb (BraseroTrackDataCfg *track,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
-						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by ISO9660 standard in its first and second versions (the most widespread ones)."
-						    "\nIt is recommended to use the third version of ISO9660 standard which is supported by most of the operating systems including Linux and all versions of Windows ©."
-						    "\nHowever MacOS X cannot read images created with version 3 of ISO9660 standard."));
+						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by the ISO9660 standard in its first and second versions (the most widespread ones)."
+						    "\nIt is recommended to use the third version of the ISO9660 standard, which is supported by most operating systems, including Linux and all versions of Windows ©."
+						    "\nHowever, Mac OS X cannot read images created with version 3 of the ISO9660 standard."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (message), _("_Add File"), GTK_RESPONSE_YES);
diff --git a/libbrasero-burn/brasero-sum-dialog.c b/libbrasero-burn/brasero-sum-dialog.c
index 8569143..9fbf4a7 100644
--- a/libbrasero-burn/brasero-sum-dialog.c
+++ b/libbrasero-burn/brasero-sum-dialog.c
@@ -158,7 +158,7 @@ brasero_sum_dialog_message_error (BraseroSumDialog *self,
 
 	return brasero_sum_dialog_message (self,
 					   _("The file integrity check could not be performed."),
-					   error ? error->message:_("An unknown error occured"),
+					   error ? error->message:_("An unknown error occurred"),
 					   GTK_MESSAGE_ERROR);
 }
 
@@ -171,7 +171,7 @@ brasero_sum_dialog_success (BraseroSumDialog *self)
 
 	return brasero_sum_dialog_message (self,
 					   _("The file integrity was performed successfully."),
-					   _("There seems to be no corrupted file on the disc"),
+					   _("There seem to be no corrupted files on the disc"),
 					   GTK_MESSAGE_INFO);
 }
 
@@ -331,7 +331,7 @@ brasero_sum_dialog_download (BraseroSumDialog *self,
 
 	brasero_tool_dialog_set_action (BRASERO_TOOL_DIALOG (self),
 					BRASERO_BURN_ACTION_FILE_COPY,
-					_("Downloading md5 file"));
+					_("Downloading MD5 file"));
 
 	id = g_timeout_add (500,
 			    brasero_sum_dialog_progress_poll,
@@ -504,7 +504,7 @@ brasero_sum_dialog_check_md5_file (BraseroSumDialog *self,
 	if (!uri) {
 		retval = brasero_sum_dialog_message (self,
 						     _("The file integrity check could not be performed."),
-						     error ? error->message:_("No md5 file was given."),
+						     error ? error->message:_("No MD5 file was given."),
 						     GTK_MESSAGE_ERROR);
 		return retval;
 	}
@@ -680,7 +680,7 @@ brasero_sum_dialog_init (BraseroSumDialog *obj)
 
 	box = gtk_vbox_new (FALSE, 6);
 
-	priv->md5_check = gtk_check_button_new_with_mnemonic (_("Use a _md5 file to check the disc"));
+	priv->md5_check = gtk_check_button_new_with_mnemonic (_("Use an _MD5 file to check the disc"));
 	gtk_widget_set_tooltip_text (priv->md5_check, _("Use an external .md5 file that stores the checksum of a disc"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->md5_check), FALSE);
 	g_signal_connect (priv->md5_check,
@@ -694,7 +694,7 @@ brasero_sum_dialog_init (BraseroSumDialog *obj)
 			    TRUE,
 			    0);
 
-	priv->md5_chooser = gtk_file_chooser_button_new (_("Open a md5 file"), GTK_FILE_CHOOSER_ACTION_OPEN);
+	priv->md5_chooser = gtk_file_chooser_button_new (_("Open an MD5 file"), GTK_FILE_CHOOSER_ACTION_OPEN);
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (priv->md5_chooser), FALSE);
 	gtk_widget_set_sensitive (priv->md5_chooser, FALSE);
 	gtk_box_pack_start (GTK_BOX (box),
diff --git a/libbrasero-burn/brasero-video-options.c b/libbrasero-burn/brasero-video-options.c
index bcf50b7..fe1082e 100644
--- a/libbrasero-burn/brasero-video-options.c
+++ b/libbrasero-burn/brasero-video-options.c
@@ -448,7 +448,7 @@ brasero_video_options_init (BraseroVideoOptions *object)
 
 	button1 = gtk_radio_button_new_with_mnemonic (NULL, _("_NTSC"));
 	priv->button_ntsc = button1;
-	gtk_widget_set_tooltip_text (button1, _("Format used mostly on the North American Continent"));
+	gtk_widget_set_tooltip_text (button1, _("Format used mostly on the North American continent"));
 	g_signal_connect (button1,
 			  "toggled",
 			  G_CALLBACK (brasero_video_options_NTSC),
@@ -547,7 +547,7 @@ brasero_video_options_init (BraseroVideoOptions *object)
 			  GTK_FILL,
 			  0, 0);
 
-	button1 = gtk_radio_button_new_with_mnemonic_from_widget (NULL, _("Create a SVCD"));
+	button1 = gtk_radio_button_new_with_mnemonic_from_widget (NULL, _("Create an SVCD"));
 	priv->svcd_button = button1;
 	gtk_table_attach (GTK_TABLE (table),
 			  button1,
diff --git a/libbrasero-burn/burn-basics.c b/libbrasero-burn/burn-basics.c
index d82cca2..a3fbc59 100644
--- a/libbrasero-burn/burn-basics.c
+++ b/libbrasero-burn/burn-basics.c
@@ -84,7 +84,7 @@ brasero_burn_action_to_string (BraseroBurnAction action)
 							N_("Transcoding song"),
 							N_("Preparing to write"),
 							N_("Writing leadin"),
-							N_("Writing CD-TEXT information"),
+							N_("Writing CD-Text information"),
 							N_("Finalizing"),
 							N_("Writing leadout"),
 						        N_("Starting to record"),
diff --git a/libbrasero-burn/burn-job.c b/libbrasero-burn/burn-job.c
index 79ffc5e..e1b4961 100644
--- a/libbrasero-burn/burn-job.c
+++ b/libbrasero-burn/burn-job.c
@@ -761,7 +761,7 @@ brasero_job_item_start (BraseroTaskItem *item,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured (%s)"),
+				     _("An internal error occurred (%s)"),
 				     g_strerror (errsv));
 
 			return BRASERO_BURN_ERR;
@@ -1212,7 +1212,7 @@ brasero_job_set_nonblocking_fd (int fd, GError **error)
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 	}
@@ -1221,7 +1221,7 @@ brasero_job_set_nonblocking_fd (int fd, GError **error)
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("An internal error occured"));
+			     _("An internal error occurred"));
 		return BRASERO_BURN_ERR;
 	}
 
diff --git a/libbrasero-burn/burn-mkisofs-base.c b/libbrasero-burn/burn-mkisofs-base.c
index 88e1320..f0ea91f 100644
--- a/libbrasero-burn/burn-mkisofs-base.c
+++ b/libbrasero-burn/burn-mkisofs-base.c
@@ -303,7 +303,7 @@ brasero_mkisofs_base_write_graft (BraseroMkisofsBase *base,
 			      * is specified. A graft point is the path (on the
 			      * disc) where a file from any source will be added
 			      * ("grafted") */
-			     _("An internal error occured"));
+			     _("An internal error occurred"));
 		return BRASERO_BURN_ERR;
 	}
 
diff --git a/libbrasero-media/brasero-media.c b/libbrasero-media/brasero-media.c
index 264b687..4ed0a26 100644
--- a/libbrasero-media/brasero-media.c
+++ b/libbrasero-media/brasero-media.c
@@ -470,7 +470,7 @@ brasero_media_get_option_group (void)
 
 	group = g_option_group_new ("brasero-media",
 				    N_("Brasero optical media library"),
-				    N_("Display options for Brasero-media library"),
+				    N_("Display options for Brasero media library"),
 				    NULL,
 				    NULL);
 	g_option_group_add_entries (group, options);
diff --git a/libbrasero-media/brasero-medium.c b/libbrasero-media/brasero-medium.c
index 6be5564..d37f4f4 100644
--- a/libbrasero-media/brasero-medium.c
+++ b/libbrasero-media/brasero-medium.c
@@ -62,7 +62,7 @@
 
 
 const gchar *types [] = {	N_("File"),
-				N_("CDROM"),
+				N_("CD-ROM"),
 				N_("CD-R"),
 				N_("CD-RW"),
 				N_("DVD-ROM"),
@@ -2342,7 +2342,7 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 						 &size,
 						 NULL);
 		if (result != BRASERO_SCSI_OK) {
-			/* CDROM */
+			/* CD-ROM */
 			priv->info = BRASERO_MEDIUM_CDROM;
 			priv->type = types [1];
 		}
diff --git a/libbrasero-utils/brasero-metadata.c b/libbrasero-utils/brasero-metadata.c
index fb463f5..327be12 100644
--- a/libbrasero-utils/brasero-metadata.c
+++ b/libbrasero-utils/brasero-metadata.c
@@ -759,7 +759,7 @@ brasero_metadata_get_duration (BraseroMetadata *self,
 			BRASERO_GET_BASENAME_FOR_DISPLAY (priv->info->uri, name);
 			priv->error = g_error_new (BRASERO_UTILS_ERROR,
 						   BRASERO_UTILS_ERROR_GENERAL,
-						   _("\"%s\" could not be handled by Gstreamer."),
+						   _("\"%s\" could not be handled by GStreamer."),
 						   name);
 			g_free (name);
 		}
diff --git a/nautilus/nautilus-burn-bar.c b/nautilus/nautilus-burn-bar.c
index f95c305..7b3954a 100644
--- a/nautilus/nautilus-burn-bar.c
+++ b/nautilus/nautilus-burn-bar.c
@@ -160,7 +160,7 @@ nautilus_disc_burn_bar_init (NautilusDiscBurnBar *bar)
                           G_CALLBACK (button_clicked_cb),
                           bar);
 
-        gtk_widget_set_tooltip_text (bar->priv->button, _("Write contents to a CD or DVD disc"));
+        gtk_widget_set_tooltip_text (bar->priv->button, _("Write contents to a CD or DVD"));
 }
 
 static void
diff --git a/nautilus/nautilus-burn-extension.c b/nautilus/nautilus-burn-extension.c
index a7fd457..74c0561 100644
--- a/nautilus/nautilus-burn-extension.c
+++ b/nautilus/nautilus-burn-extension.c
@@ -163,7 +163,7 @@ nautilus_disc_burn_is_empty (GtkWindow *toplevel)
 			return TRUE;
 		}
 
-		string = g_strdup_printf ("%s.", _("An internal error occured"));
+		string = g_strdup_printf ("%s.", _("An internal error occurred"));
 		brasero_utils_message_dialog (GTK_WIDGET (toplevel),
 					      string,
 					      error ? error->message:NULL,
@@ -480,7 +480,7 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
                 /* Whether or not this file is local is not a problem */
                 item = nautilus_menu_item_new ("NautilusDiscBurn::write_iso",
                                                _("_Write to Discâ?¦"),
-                                               _("Write disc image to a CD or DVD disc"),
+                                               _("Write disc image to a CD or DVD"),
                                                "media-optical-data-new");
                 g_object_set_data (G_OBJECT (item), "file_info", file_info);
                 g_object_set_data (G_OBJECT (item), "window", window);
@@ -549,7 +549,7 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 			/* user may want to copy it ... */
 			item = nautilus_menu_item_new ("NautilusDiscBurn::copy_disc",
 						       _("_Copy Discâ?¦"),
-						       _("Create a copy of this CD or DVD disc"),
+						       _("Create a copy of this CD or DVD"),
 						       "media-optical-copy");
 			g_object_set_data (G_OBJECT (item), "file_info", file_info);
 			g_object_set_data (G_OBJECT (item), "window", window);
@@ -563,7 +563,7 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 			/* ... or if it's a rewritable medium to blank it ... */
 			item = nautilus_menu_item_new ("NautilusDiscBurn::blank_disc",
 						       _("_Blank Discâ?¦"),
-						       _("Blank this CD or DVD disc"),
+						       _("Blank this CD or DVD"),
 						       "media-optical-blank");
 			g_object_set_data (G_OBJECT (item), "file_info", file_info);
 			g_object_set_data (G_OBJECT (item), "window", window);
@@ -580,7 +580,7 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 			/* ... or verify medium. */
 			item = nautilus_menu_item_new ("NautilusDiscBurn::check_disc",
 						       _("_Check Discâ?¦"),
-						       _("Check the data integrity on this CD or DVD disc"),
+						       _("Check the data integrity on this CD or DVD"),
 						       NULL);
 			g_object_set_data (G_OBJECT (item), "file_info", file_info);
 			g_object_set_data (G_OBJECT (item), "window", window);
@@ -626,7 +626,7 @@ nautilus_disc_burn_get_background_items (NautilusMenuProvider *provider,
 
                 item = nautilus_menu_item_new ("NautilusDiscBurn::write_menu",
                                                _("_Write to Discâ?¦"),
-                                               _("Write contents to a CD or DVD disc"),
+                                               _("Write contents to a CD or DVD"),
                                                "brasero");
                 g_signal_connect (item, "activate",
                                   G_CALLBACK (write_activate_cb),
diff --git a/plugins/cdrdao/burn-cdrdao-common.h b/plugins/cdrdao/burn-cdrdao-common.h
index 6654f4f..fe8421f 100644
--- a/plugins/cdrdao/burn-cdrdao-common.h
+++ b/plugins/cdrdao/burn-cdrdao-common.h
@@ -35,7 +35,7 @@
 
 G_BEGIN_DECLS
 
-#define CDRDAO_DESCRIPTION		N_("Cdrdao burning suite")
+#define CDRDAO_DESCRIPTION		N_("cdrdao burning suite")
 
 G_END_DECLS
 
diff --git a/plugins/cdrdao/burn-cdrdao.c b/plugins/cdrdao/burn-cdrdao.c
index 9396c1c..47f3204 100644
--- a/plugins/cdrdao/burn-cdrdao.c
+++ b/plugins/cdrdao/burn-cdrdao.c
@@ -693,7 +693,7 @@ brasero_cdrdao_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_BURN_FLAG_NONE);
 
 	use_raw = brasero_plugin_conf_option_new (GCONF_KEY_RAW_FLAG,
-						  _("Enable \"--driver generic-mmc-raw\" flag (see cdrdao manual)"),
+						  _("Enable the \"--driver generic-mmc-raw\" flag (see cdrdao manual)"),
 						  BRASERO_PLUGIN_OPTION_BOOL);
 
 	brasero_plugin_add_conf_option (plugin, use_raw);
diff --git a/plugins/cdrdao/burn-toc2cue.c b/plugins/cdrdao/burn-toc2cue.c
index 0eb131c..7bd1204 100644
--- a/plugins/cdrdao/burn-toc2cue.c
+++ b/plugins/cdrdao/burn-toc2cue.c
@@ -329,7 +329,7 @@ brasero_toc2cue_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "toc2cue",
-			       _("Toc2cue converts .toc files into .cue files"),
+			       _("toc2cue converts .toc files into .cue files"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/cdrkit/burn-cdrkit.h b/plugins/cdrkit/burn-cdrkit.h
index 05a539e..80887bb 100644
--- a/plugins/cdrkit/burn-cdrkit.h
+++ b/plugins/cdrkit/burn-cdrkit.h
@@ -35,7 +35,7 @@
 
 G_BEGIN_DECLS
 
-#define CDRKIT_DESCRIPTION		N_("Cdrkit burning suite")
+#define CDRKIT_DESCRIPTION		N_("cdrkit burning suite")
 
 G_END_DECLS
 
diff --git a/plugins/cdrkit/burn-genisoimage.c b/plugins/cdrkit/burn-genisoimage.c
index 602836c..bf92707 100644
--- a/plugins/cdrkit/burn-genisoimage.c
+++ b/plugins/cdrkit/burn-genisoimage.c
@@ -368,7 +368,7 @@ brasero_genisoimage_set_argv_image (BraseroGenisoimage *genisoimage,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
diff --git a/plugins/cdrkit/burn-readom.c b/plugins/cdrkit/burn-readom.c
index 11db0a6..3f255e4 100644
--- a/plugins/cdrkit/burn-readom.c
+++ b/plugins/cdrkit/burn-readom.c
@@ -126,7 +126,7 @@ brasero_readom_read_stderr (BraseroProcess *process, const gchar *line)
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("An internal error occured")));
+						_("An internal error occurred")));
 	}
 	else if (strstr (line, "No space left on device")) {
 		/* This is necessary as readcd won't return an error code on exit */
@@ -367,7 +367,7 @@ brasero_readom_set_argv (BraseroProcess *process,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("An internal error occured"));
+			     _("An internal error occurred"));
 		return BRASERO_BURN_ERR;
 	}
 
diff --git a/plugins/cdrtools/burn-cdrtools.h b/plugins/cdrtools/burn-cdrtools.h
index c244583..c28f48b 100644
--- a/plugins/cdrtools/burn-cdrtools.h
+++ b/plugins/cdrtools/burn-cdrtools.h
@@ -35,7 +35,7 @@
 
 G_BEGIN_DECLS
 
-#define CDRTOOLS_DESCRIPTION		N_("Cdrtools burning suite")
+#define CDRTOOLS_DESCRIPTION		N_("cdrtools burning suite")
 
 G_END_DECLS
 
diff --git a/plugins/cdrtools/burn-mkisofs.c b/plugins/cdrtools/burn-mkisofs.c
index c9d91a5..ccbaf41 100644
--- a/plugins/cdrtools/burn-mkisofs.c
+++ b/plugins/cdrtools/burn-mkisofs.c
@@ -369,7 +369,7 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -532,7 +532,7 @@ brasero_mkisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "mkisofs",
-			       _("Use mkisofs to create image from a file selection"),
+			       _("Use mkisofs to create an image from a file selection"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/cdrtools/burn-readcd.c b/plugins/cdrtools/burn-readcd.c
index b26ed87..620d5e1 100644
--- a/plugins/cdrtools/burn-readcd.c
+++ b/plugins/cdrtools/burn-readcd.c
@@ -127,7 +127,7 @@ brasero_readcd_read_stderr (BraseroProcess *process, const gchar *line)
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("An internal error occured")));
+						_("An internal error occurred")));
 	}
 	else if (strstr (line, "No space left on device")) {
 		/* This is necessary as readcd won't return an error code on exit */
@@ -377,7 +377,7 @@ brasero_readcd_set_argv (BraseroProcess *process,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("An internal error occured"));
+			     _("An internal error occurred"));
 		return BRASERO_BURN_ERR;
 	}
 
diff --git a/plugins/checksum/burn-checksum-files.c b/plugins/checksum/burn-checksum-files.c
index 4c0991f..c289b06 100644
--- a/plugins/checksum/burn-checksum-files.c
+++ b/plugins/checksum/burn-checksum-files.c
@@ -1464,7 +1464,7 @@ brasero_checksum_files_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("File Checksum"),
-			       _("Allows to check file integrities on a disc"),
+			       _("Allow file integrities to be checked on a disc"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/checksum/burn-checksum-image.c b/plugins/checksum/burn-checksum-image.c
index a6d67ee..06297ae 100644
--- a/plugins/checksum/burn-checksum-image.c
+++ b/plugins/checksum/burn-checksum-image.c
@@ -826,7 +826,7 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("Image Checksum"),
-			       _("Allows to check data integrity on disc after it is burned"),
+			       _("Allows data integrity to be checked on disc after it is burned"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/dvdcss/burn-dvdcss.c b/plugins/dvdcss/burn-dvdcss.c
index 2d0b84e..fd3697a 100644
--- a/plugins/dvdcss/burn-dvdcss.c
+++ b/plugins/dvdcss/burn-dvdcss.c
@@ -134,7 +134,7 @@ error_version:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("Libdvdcss version %s is not supported.\nPlease install libdvdcss version 1.2.x"),
+		     _("libdvdcss version %s is not supported.\nPlease install libdvdcss version 1.2.x"),
 		     dvdcss_interface_2);
 	g_module_close (module);
 	return FALSE;
@@ -144,7 +144,7 @@ error_loading:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("Libdvdcss could not be loaded properly"));
+		     _("libdvdcss could not be loaded properly"));
 	g_module_close (module);
 	return FALSE;
 }
@@ -681,7 +681,7 @@ brasero_dvdcss_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "dvdcss",
-			       _("Dvdcss allows to read css encrypted video DVDs"),
+			       _("dvdcss allows to CSS-encrypted video DVDs to be read"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/growisofs/burn-growisofs-common.h b/plugins/growisofs/burn-growisofs-common.h
index f651a57..510bd24 100644
--- a/plugins/growisofs/burn-growisofs-common.h
+++ b/plugins/growisofs/burn-growisofs-common.h
@@ -35,7 +35,7 @@
 
 G_BEGIN_DECLS
 
-#define GROWISOFS_DESCRIPTION		N_("Growisofs burning suite")
+#define GROWISOFS_DESCRIPTION		N_("growisofs burning suite")
 
 G_END_DECLS
 
diff --git a/plugins/growisofs/burn-growisofs.c b/plugins/growisofs/burn-growisofs.c
index 556930f..12ede1f 100644
--- a/plugins/growisofs/burn-growisofs.c
+++ b/plugins/growisofs/burn-growisofs.c
@@ -747,7 +747,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "growisofs",
-			       _("Growisofs burns DVDs"),
+			       _("growisofs burns DVDs"),
 			       "Philippe Rouquier",
 			       7);
 
diff --git a/plugins/libburnia/burn-libburn-common.c b/plugins/libburnia/burn-libburn-common.c
index 3ceaa48..7bc37d2 100644
--- a/plugins/libburnia/burn-libburn-common.c
+++ b/plugins/libburnia/burn-libburn-common.c
@@ -155,7 +155,7 @@ brasero_libburn_common_ctx_new (BraseroJob *job,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libburn library could not be initialized"));
+			     _("libburn library could not be initialized"));
 		return NULL;
 	}
 
diff --git a/plugins/libburnia/burn-libburn.c b/plugins/libburnia/burn-libburn.c
index 3e4b1af..0c0455e 100644
--- a/plugins/libburnia/burn-libburn.c
+++ b/plugins/libburnia/burn-libburn.c
@@ -239,7 +239,7 @@ brasero_libburn_add_track (struct burn_session *session,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libburn track could not be created"));
+			     _("libburn track could not be created"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -247,7 +247,7 @@ brasero_libburn_add_track (struct burn_session *session,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libburn track could not be created"));
+			     _("libburn track could not be created"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -713,7 +713,7 @@ brasero_libburn_start_erase (BraseroLibburn *self,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
 			     /* Translators: %s is the error returned by libburn */
-			     _("An internal error occured (%s)"),
+			     _("An internal error occurred (%s)"),
 			     reasons);
 		return BRASERO_BURN_ERR;
 	}
@@ -852,7 +852,7 @@ brasero_libburn_clock_tick (BraseroJob *job)
 		brasero_job_error (job,
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 		return BRASERO_BURN_OK;
 	}
 
@@ -883,7 +883,7 @@ brasero_libburn_clock_tick (BraseroJob *job)
 		brasero_job_error (job,
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 		return BRASERO_BURN_OK;
 	}
 
@@ -970,7 +970,7 @@ brasero_libburn_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "libburn",
-			       _("Libburn burns CD(RW), DVD+/-(RW)"),
+			       _("libburn burns CD(RW), DVD+/-(RW)"),
 			       "Philippe Rouquier",
 			       15);
 
diff --git a/plugins/libburnia/burn-libburnia.h b/plugins/libburnia/burn-libburnia.h
index f6ad38d..3391eb1 100644
--- a/plugins/libburnia/burn-libburnia.h
+++ b/plugins/libburnia/burn-libburnia.h
@@ -35,7 +35,7 @@
 
 G_BEGIN_DECLS
 
-#define LIBBURNIA_DESCRIPTION		N_("Libburnia burning suite")
+#define LIBBURNIA_DESCRIPTION		N_("libburnia burning suite")
 
 G_END_DECLS
 
diff --git a/plugins/libburnia/burn-libisofs.c b/plugins/libburnia/burn-libisofs.c
index a26fad3..e84e3fa 100644
--- a/plugins/libburnia/burn-libisofs.c
+++ b/plugins/libburnia/burn-libisofs.c
@@ -325,7 +325,7 @@ brasero_libisofs_create_image (BraseroLibisofs *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libisofs could not be initialized."));
+			     _("libisofs could not be initialized."));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -723,7 +723,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 result);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("Libisofs reported an error while creating directory \"%s\""),
+								   _("libisofs reported an error while creating directory \"%s\""),
 								   graft->path);
 					g_free (path_name);
 					goto end;
@@ -738,7 +738,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 result);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("Libisofs reported an error while adding contents to directory \"%s\" (%x)"),
+								   _("libisofs reported an error while adding contents to directory \"%s\" (%x)"),
 								   graft->path,
 								   result);
 					g_free (path_name);
@@ -761,7 +761,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 err);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("Libisofs reported an error while adding file at path \"%s\""),
+								   _("libisofs reported an error while adding file at path \"%s\""),
 								   graft->path);
 					g_free (path_name);
 					goto end;
@@ -777,7 +777,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 								 err);
 						priv->error = g_error_new (BRASERO_BURN_ERROR,
 									   BRASERO_BURN_ERROR_GENERAL,
-									   _("Libisofs reported an error while adding file at path \"%s\""),
+									   _("libisofs reported an error while adding file at path \"%s\""),
 									   graft->path);
 						g_free (path_name);
 						goto end;
@@ -790,7 +790,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 		else if (iso_tree_add_new_dir (ISO_DIR (parent), path_name, NULL) < 0) {
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
-						   _("Libisofs reported an error while creating directory \"%s\""),
+						   _("libisofs reported an error while creating directory \"%s\""),
 						   graft->path);
 			g_free (path_name);
 			goto end;
@@ -864,7 +864,7 @@ brasero_libisofs_create_volume (BraseroLibisofs *self, GError **error)
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libisofs could not be initialized."));
+			     _("libisofs could not be initialized."));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -1041,7 +1041,7 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "libisofs",
-			       _("Libisofs creates disc images from files"),
+			       _("libisofs creates disc images from files"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/local-track/burn-local-image.c b/plugins/local-track/burn-local-image.c
index 8a2729d..ade53a5 100644
--- a/plugins/local-track/burn-local-image.c
+++ b/plugins/local-track/burn-local-image.c
@@ -908,7 +908,7 @@ brasero_local_track_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("File Downloader"),
-			       _("Allows to burn files not stored locally"),
+			       _("Allows files not stored locally to be burned"),
 			       "Philippe Rouquier",
 			       10);
 
diff --git a/plugins/local-track/burn-uri.c b/plugins/local-track/burn-uri.c
index 00fadb4..ed54478 100644
--- a/plugins/local-track/burn-uri.c
+++ b/plugins/local-track/burn-uri.c
@@ -744,7 +744,7 @@ brasero_burn_uri_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("CD/DVD Creator Folder"),
-			       _("Allows to burn files added to \"CD/DVD Creator Folder\" in Nautilus"),
+			       _("Allows files added to the \"CD/DVD Creator Folder\" in Nautilus to be burned"),
 			       "Philippe Rouquier",
 			       11);
 
diff --git a/plugins/transcode/burn-normalize.c b/plugins/transcode/burn-normalize.c
index 741f38d..aff0502 100644
--- a/plugins/transcode/burn-normalize.c
+++ b/plugins/transcode/burn-normalize.c
@@ -644,7 +644,7 @@ brasero_normalize_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       N_("Normalize"),
-			       _("Normalize allows to set consistent sound levels between tracks"),
+			       _("Normalize allows you to set consistent sound levels between tracks"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/plugins/transcode/burn-transcode.c b/plugins/transcode/burn-transcode.c
index 5da8ce4..b723f63 100644
--- a/plugins/transcode/burn-transcode.c
+++ b/plugins/transcode/burn-transcode.c
@@ -806,7 +806,7 @@ brasero_transcode_create_sibling_image (BraseroTranscode *transcode,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
 			     /* Translators: the %s is the error message from errno */
-			     _("An internal error occured (%s)"),
+			     _("An internal error occurred (%s)"),
 			     g_strerror (errsv));
 
 		goto error;
diff --git a/plugins/transcode/burn-vob.c b/plugins/transcode/burn-vob.c
index 1070bcb..e03a1be 100644
--- a/plugins/transcode/burn-vob.c
+++ b/plugins/transcode/burn-vob.c
@@ -1317,7 +1317,7 @@ brasero_vob_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "transcode2vob",
-			       _("Vob allows to transcode any video file to a format suitable for video DVDs"),
+			       _("Vob allows any video file to be transcoded to a format suitable for video DVDs"),
 			       "Philippe Rouquier",
 			       0);
 
diff --git a/src/brasero-app.c b/src/brasero-app.c
index 253a3da..a1ed6a5 100644
--- a/src/brasero-app.c
+++ b/src/brasero-app.c
@@ -125,7 +125,7 @@ static GtkActionEntry entries[] = {
 	{"HelpMenu", NULL, N_("_Help")},
 
 	{"Plugins", NULL, N_("P_lugins"), NULL,
-	 N_("Choose plugins for brasero"), G_CALLBACK (on_prefs_cb)},
+	 N_("Choose plugins for Brasero"), G_CALLBACK (on_prefs_cb)},
 
 	{"Eject", "media-eject", N_("E_ject"), NULL,
 	 N_("Eject a disc"), G_CALLBACK (on_eject_cb)},
diff --git a/src/brasero-audio-disc.c b/src/brasero-audio-disc.c
index b8917c4..9917df1 100644
--- a/src/brasero-audio-disc.c
+++ b/src/brasero-audio-disc.c
@@ -151,7 +151,7 @@ static GtkActionEntry entries[] = {
 	{"ContextualMenu", NULL, N_("Menu")},
 	{"OpenSong", GTK_STOCK_OPEN, NULL, NULL, N_("Open the selected files"),
 	 G_CALLBACK (brasero_audio_disc_open_activated_cb)},
-	{"EditSong", GTK_STOCK_PROPERTIES, N_("_Edit Informationâ?¦"), NULL, N_("Edit the track information (start, end, author, ...)"),
+	{"EditSong", GTK_STOCK_PROPERTIES, N_("_Edit Informationâ?¦"), NULL, N_("Edit the track information (start, end, author, etc.)"),
 	 G_CALLBACK (brasero_audio_disc_edit_information_cb)},
 	{"DeleteAudio", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected files from the project"),
 	 G_CALLBACK (brasero_audio_disc_delete_activated_cb)},
@@ -639,7 +639,7 @@ brasero_audio_disc_file_type_error_dialog (BraseroAudioDisc *disc,
 	gchar *name;
 
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	primary = g_strdup_printf (_("\"%s\" could not be handled by Gstreamer."), name);
+	primary = g_strdup_printf (_("\"%s\" could not be handled by GStreamer."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
 			   _("Make sure the appropriate codec is installed"),
@@ -658,7 +658,7 @@ brasero_audio_disc_video_file_dialog (BraseroAudioDisc *disc,
 	gchar *name;
 
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	string = g_strdup_printf (_("Do you want to add \"%s\" which is a video file?"), name);
+	string = g_strdup_printf (_("Do you want to add \"%s\", which is a video file?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
@@ -849,9 +849,9 @@ brasero_audio_disc_wav_dts_file_dialog (BraseroAudioDisc *disc)
 
 	message = brasero_notify_message_add (BRASERO_NOTIFY (disc->priv->message),
 					      _("Do you want to create an audio CD with DTS tracks?"),
-					      _("Some of the selected songs are suitable to create DTS tracks."
-					        "\nThis type of audio CD track provides a higher quality for sound but can only be played by specific digital players."
-					        "\nNOTE: if you agree normalization will not be applied to these tracks."),
+					      _("Some of the selected songs are suitable for creating DTS tracks."
+					        "\nThis type of audio CD track provides a higher quality of sound but can only be played by specific digital players."
+					        "\nNote: if you agree, normalization will not be applied to these tracks."),
 					      0,
 					      BRASERO_AUDIO_DISC_CONTEXT);
 
diff --git a/src/brasero-data-disc.c b/src/brasero-data-disc.c
index 322b29e..ff3d67b 100644
--- a/src/brasero-data-disc.c
+++ b/src/brasero-data-disc.c
@@ -215,7 +215,7 @@ brasero_data_disc_import_failure_dialog (BraseroDataDisc *disc,
 {
 	brasero_app_alert (brasero_app_get_default (),
 			   _("The session could not be imported."),
-			   error?error->message:_("An unknown error occured"),
+			   error?error->message:_("An unknown error occurred"),
 			   GTK_MESSAGE_WARNING);
 }
 
@@ -842,7 +842,7 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 	if (priv->reject_deep_files)
 		return FALSE;
 
-	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"), name);
+	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of the ISO9660 standard to support it?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
@@ -850,9 +850,9 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by ISO9660 standard in its first and second versions (the most widespread ones)."
-						    "\nIt is recommended to use the third version of ISO9660 standard which is supported by most of the operating systems including Linux and all versions of Windows ©."
-						    "\nHowever MacOS X cannot read images created with version 3 of ISO9660 standard."));
+						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by the ISO9660 standard in its first and second versions (the most widespread ones)."
+						    "\nIt is recommended to use the third version of the ISO9660 standard, which is supported by most operating systems, including Linux and all versions of Windows ©."
+						    "\nHowever, Mac OS X cannot read images created with version 3 of the ISO9660 standard."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
@@ -897,7 +897,7 @@ brasero_data_disc_deep_directory_cb (BraseroTrackDataCfg *project,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  _("The children of this directory will have 7 parent directories."
 						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
-						    "\nNOTE: Such a file hierarchy is known to work on linux."));
+						    "\nNote: Such a file hierarchy is known to work on Linux."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
@@ -1116,7 +1116,7 @@ brasero_data_disc_session_available_cb (BraseroTrackDataCfg *session,
 		/* ask user */
 		volume_name = brasero_volume_get_name (BRASERO_VOLUME (medium));
 		/* Translators: %s is the name of the volume to import */
-		string = g_strdup_printf (_("Do you want to import the session from \'%s\'?"), volume_name);
+		string = g_strdup_printf (_("Do you want to import the session from \"%s\"?"), volume_name);
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
 						      string,
 						      _("That way, old files from previous sessions will be usable after burning."),
diff --git a/src/brasero-eject-dialog.c b/src/brasero-eject-dialog.c
index bb875ad..f099ef8 100644
--- a/src/brasero-eject-dialog.c
+++ b/src/brasero-eject-dialog.c
@@ -95,7 +95,7 @@ brasero_eject_dialog_activate (GtkDialog *dialog,
 
 		brasero_app_alert (brasero_app_get_default (),
 		                   string,
-		                   error?error->message:_("An unknown error occured"),
+		                   error?error->message:_("An unknown error occurred"),
 		                   GTK_MESSAGE_ERROR);
 
 		if (error)
diff --git a/src/brasero-layout.c b/src/brasero-layout.c
index 64b71ea..e14fc2b 100644
--- a/src/brasero-layout.c
+++ b/src/brasero-layout.c
@@ -122,7 +122,7 @@ const GtkToggleActionEntry entries [] = {
 /** see #547687 **/
 const GtkRadioActionEntry radio_entries [] = {
 	{ "HView", NULL, N_("_Horizontal Layout"),
-	  NULL, N_("Set an horizontal layout"), 1 },
+	  NULL, N_("Set a horizontal layout"), 1 },
 
 	{ "VView", NULL, N_("_Vertical Layout"),
 	  NULL, N_("Set a vertical layout"), 0 },
diff --git a/src/brasero-multi-song-props.c b/src/brasero-multi-song-props.c
index cfd10b3..b46d5ca 100644
--- a/src/brasero-multi-song-props.c
+++ b/src/brasero-multi-song-props.c
@@ -207,7 +207,7 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 	priv->title = brasero_rename_new ();
 	gtk_widget_show (priv->title);
 	gtk_widget_set_tooltip_text (priv->title,
-				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
+				     _("This information will be written to the disc using CD-Text technology. It can be read and displayed by some audio CD players."));
 
 	title = g_strdup_printf ("<b>%s</b>", _("Song titles"));
 	frame = brasero_utils_pack_properties (title, priv->title, NULL);
@@ -248,7 +248,7 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 	gtk_entry_set_text (GTK_ENTRY (priv->artist), _("<Keep current values>"));
 	gtk_table_attach_defaults (GTK_TABLE (table), priv->artist, 1, 2, 1, 2);
 	gtk_widget_set_tooltip_text (priv->artist,
-				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
+				     _("This information will be written to the disc using CD-Text technology. It can be read and displayed by some audio CD players."));
 	g_signal_connect (priv->artist,
 			  "focus-in-event",
 			  G_CALLBACK (brasero_multi_song_props_entry_focus_in),
@@ -269,7 +269,7 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 	gtk_entry_set_text (GTK_ENTRY (priv->composer), _("<Keep current values>"));
 	gtk_table_attach_defaults (GTK_TABLE (table), priv->composer, 1, 2, 2, 3);
 	gtk_widget_set_tooltip_text (priv->composer,
-				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
+				     _("This information will be written to the disc using CD-Text technology. It can be read and displayed by some audio CD players."));
 	g_signal_connect (priv->composer,
 			  "focus-in-event",
 			  G_CALLBACK (brasero_multi_song_props_entry_focus_in),
diff --git a/src/brasero-playlist.c b/src/brasero-playlist.c
index 08a560f..c470a65 100644
--- a/src/brasero-playlist.c
+++ b/src/brasero-playlist.c
@@ -803,7 +803,7 @@ brasero_playlist_dialog_error (BraseroPlaylist *playlist, const gchar *uri)
 	primary = g_strdup_printf (_("Error parsing playlist \"%s\"."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
-			   _("An unknown error occured"),
+			   _("An unknown error occurred"),
 			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
diff --git a/src/brasero-project-manager.c b/src/brasero-project-manager.c
index 8b964b1..28b8af9 100644
--- a/src/brasero-project-manager.c
+++ b/src/brasero-project-manager.c
@@ -112,7 +112,7 @@ static GtkActionEntry entries [] = {
 	{"NewData", "media-optical-data-new", N_("New _Data Project"), NULL,
 	 N_("Create a CD/DVD containing any type of data that can only be read on a computer"), G_CALLBACK (brasero_project_manager_new_data_prj_cb)},
 	{"NewVideo", "media-optical-video-new", N_("New _Video Project"), NULL,
-	 N_("Create a video DVD or a SVCD that are readable on TV readers"), G_CALLBACK (brasero_project_manager_new_video_prj_cb)},
+	 N_("Create a video DVD or an SVCD that are readable on TV readers"), G_CALLBACK (brasero_project_manager_new_video_prj_cb)},
 	{"NewCopy", "media-optical-copy", N_("Copy _Discâ?¦"), NULL,
 	 N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hard disk or on another CD/DVD"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
 	{"NewIso", "iso-image-burn", N_("_Burn Imageâ?¦"), NULL,
diff --git a/src/brasero-project-type-chooser.c b/src/brasero-project-type-chooser.c
index a07362a..59fb31b 100644
--- a/src/brasero-project-type-chooser.c
+++ b/src/brasero-project-type-chooser.c
@@ -80,8 +80,8 @@ static ItemDescription items [] = {
 	"media-optical-data-new",
 	BRASERO_PROJECT_TYPE_DATA},
        {N_("_Video project"),
-	N_("Create a video DVD or a SVCD"),
-	N_("Create a video DVD or a SVCD that are readable on TV readers"),
+	N_("Create a video DVD or an SVCD"),
+	N_("Create a video DVD or an SVCD that are readable on TV readers"),
 	"media-optical-video-new",
 	BRASERO_PROJECT_TYPE_VIDEO},
        {N_("Disc _copy"),
diff --git a/src/brasero-project.c b/src/brasero-project.c
index 687a1a2..c38b400 100644
--- a/src/brasero-project.c
+++ b/src/brasero-project.c
@@ -702,7 +702,7 @@ brasero_disc_get_use_info_notebook (BraseroProject *project)
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("drag files in this area from the selection pane or from the file manager"), -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("double click on files in the selection pane"), -1, "TextBody", NULL);
+	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("double-click on files in the selection pane"), -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("copy files (from file manager for example) and paste in this area"), -1, "TextBody", NULL);
 	gtk_text_buffer_insert (buffer, &iter, "\n\n\n", -1);
@@ -822,7 +822,7 @@ brasero_project_update_project_size (BraseroProject *project)
 	string = brasero_project_get_sectors_string (sectors, session_type);
 	brasero_track_type_free (session_type);
 
-	size_str = g_strdup_printf (_("Project estimated size: %s"), string);
+	size_str = g_strdup_printf (_("Estimated project size: %s"), string);
 	g_free (string);
 
 	gtk_statusbar_push (GTK_STATUSBAR (status), project->priv->status_ctx, size_str);
@@ -967,7 +967,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 
 			message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
 							      _("Would you like to burn the selection of files across several media?"),
-							      _("The size of the project is too large for the disc even with the overburn option."),
+							      _("The project is too large for the disc even with the overburn option."),
 							      -1,
 							      BRASERO_NOTIFY_CONTEXT_SIZE);
 			brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
@@ -984,7 +984,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		else
 			brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
 						    _("Please choose another CD or DVD or insert a new one."),
-						    _("The size of the project is too large for the disc even with the overburn option."),
+						    _("The project is too large for the disc even with the overburn option."),
 						    -1,
 						    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
@@ -994,16 +994,16 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		project->priv->empty = FALSE;
 		project->priv->oversized = TRUE;
 		message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-						      _("Would you like to burn beyond the disc reported capacity?"),
-						      _("The size of the project is too large for the disc and you must remove files from the project otherwise."
-							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
-							"\nNOTE: This option might cause failure."),
+						      _("Would you like to burn beyond the disc's reported capacity?"),
+						      _("The project is too large for the disc and you must remove files from it."
+							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognized and therefore needs the overburn option."
+							"\nNote: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
 		brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Overburn"),
-					   _("Burn beyond the disc reported capacity"),
+					   _("Burn beyond the disc's reported capacity"),
 					   GTK_RESPONSE_OK);
 
 		g_signal_connect (message,
@@ -2364,7 +2364,7 @@ brasero_project_not_saved_dialog (BraseroProject *project)
 	error = xmlGetLastError ();
 	brasero_app_alert (brasero_app_get_default (),
 			   _("Your project has not been saved."),
-			   error? error->message:_("An unknown error occured"),
+			   error? error->message:_("An unknown error occurred"),
 			   GTK_MESSAGE_ERROR);
 	xmlResetLastError ();
 }
@@ -2504,15 +2504,15 @@ brasero_project_save_project_ask_for_path (BraseroProject *project,
 		combo = gtk_combo_box_new_text ();
 		gtk_widget_show (combo);
 
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as Brasero audio project"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a Brasero audio project"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a plain text list"));
 
 #ifdef BUILD_PLAYLIST
 
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a PLS playlist"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an M3U playlist"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a XSPF playlist"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an IRIVER playlist"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an XSPF playlist"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an iriver playlist"));
 
 #endif
 
diff --git a/src/brasero-rename.c b/src/brasero-rename.c
index ed86ca6..725d5e4 100644
--- a/src/brasero-rename.c
+++ b/src/brasero-rename.c
@@ -118,17 +118,17 @@ brasero_rename_delete_string (BraseroRename *self,
 {
 	BraseroRenamePrivate *priv;
 	const gchar *text;
-	gchar *occurence;
+	gchar *occurrence;
 
 	priv = BRASERO_RENAME_PRIVATE (self);
 
 	text = gtk_entry_get_text (GTK_ENTRY (priv->delete_entry));
-	occurence = g_strstr_len (name, -1, text);
+	occurrence = g_strstr_len (name, -1, text);
 
-	if (!occurence)
+	if (!occurrence)
 		return NULL;
 
-	return g_strdup_printf ("%.*s%s", (int) (occurence - name), name, occurence + strlen (text));
+	return g_strdup_printf ("%.*s%s", (int) (occurrence - name), name, occurrence + strlen (text));
 }
 
 static gchar *
@@ -138,18 +138,18 @@ brasero_rename_substitute_string (BraseroRename *self,
 	BraseroRenamePrivate *priv;
 	const gchar *joker;
 	const gchar *text;
-	gchar *occurence;
+	gchar *occurrence;
 
 	priv = BRASERO_RENAME_PRIVATE (self);
 
 	text = gtk_entry_get_text (GTK_ENTRY (priv->substitute_entry));
-	occurence = g_strstr_len (name, -1, text);
+	occurrence = g_strstr_len (name, -1, text);
 
-	if (!occurence)
+	if (!occurrence)
 		return NULL;
 
 	joker = gtk_entry_get_text (GTK_ENTRY (priv->joker_entry));
-	return g_strdup_printf ("%.*s%s%s", (int) (occurence - name), name, joker, occurence + strlen (text));
+	return g_strdup_printf ("%.*s%s%s", (int) (occurrence - name), name, joker, occurrence + strlen (text));
 }
 
 static gchar *
@@ -312,7 +312,7 @@ brasero_rename_init (BraseroRename *object)
 
 	/* Translators: This finishes previous action "Insert". It goes like
 	 * this: "Insert" [Entry] "at the beginning". */
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("at the begining"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("at the beginning"));
 
 	/* Translators: This finishes previous action "Insert". It goes like
 	 * this: "Insert" [Entry] "at the end". */
@@ -327,7 +327,7 @@ brasero_rename_init (BraseroRename *object)
 	gtk_widget_show (hbox);
 	gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), hbox, NULL);
 
-	label = gtk_label_new (_("Delete every occurence of"));
+	label = gtk_label_new (_("Delete every occurrence of"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
diff --git a/src/brasero-song-properties.c b/src/brasero-song-properties.c
index 11acaff..183eb72 100644
--- a/src/brasero-song-properties.c
+++ b/src/brasero-song-properties.c
@@ -183,7 +183,7 @@ brasero_song_props_init (BraseroSongProps *obj)
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	gtk_table_attach_defaults (GTK_TABLE (table), obj->priv->title, 1, 2, 0, 1);
 	gtk_widget_set_tooltip_text (obj->priv->title,
-			      _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
+			      _("This information will be written to the disc using CD-Text technology. It can be read and displayed by some audio CD players."));
 
 	label = gtk_label_new (_("Artist:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -195,7 +195,7 @@ brasero_song_props_init (BraseroSongProps *obj)
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 	gtk_table_attach_defaults (GTK_TABLE (table), obj->priv->artist, 1, 2, 1, 2);
 	gtk_widget_set_tooltip_text (obj->priv->artist,
-				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
+				     _("This information will be written to the disc using CD-Text technology. It can be read and displayed by some audio CD players."));
 
 	label = gtk_label_new (_("Composer:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -207,7 +207,7 @@ brasero_song_props_init (BraseroSongProps *obj)
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 	gtk_table_attach_defaults (GTK_TABLE (table), obj->priv->composer, 1, 2, 2, 3);
 	gtk_widget_set_tooltip_text (obj->priv->composer,
-			      _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
+			      _("This information will be written to the disc using CD-Text technology. It can be read and displayed by some audio CD players."));
 
 	label = gtk_label_new ("ISRC:");
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
diff --git a/src/brasero-split-dialog.c b/src/brasero-split-dialog.c
index 28ed679..1494a18 100644
--- a/src/brasero-split-dialog.c
+++ b/src/brasero-split-dialog.c
@@ -621,7 +621,7 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 
 	if (error) {
 		brasero_utils_message_dialog (GTK_WIDGET (self),
-					      _("An error occured while detecting silences."),
+					      _("An error occurred while detecting silences."),
 					      error->message,
 					      GTK_MESSAGE_ERROR);
 		return;
diff --git a/src/brasero-video-disc.c b/src/brasero-video-disc.c
index 4b18408..ca5f259 100644
--- a/src/brasero-video-disc.c
+++ b/src/brasero-video-disc.c
@@ -100,7 +100,7 @@ static GtkActionEntry entries[] = {
 	{"ContextualMenu", NULL, N_("Menu")},
 	{"OpenVideo", GTK_STOCK_OPEN, NULL, NULL, N_("Open the selected video"),
 	 G_CALLBACK (brasero_video_disc_open_activated_cb)},
-	{"EditVideo", GTK_STOCK_PROPERTIES, N_("_Edit Informationâ?¦"), NULL, N_("Edit the video information (start, end, author, ...)"),
+	{"EditVideo", GTK_STOCK_PROPERTIES, N_("_Edit Informationâ?¦"), NULL, N_("Edit the video information (start, end, author, etc.)"),
 	 G_CALLBACK (brasero_video_disc_edit_information_cb)},
 	{"DeleteVideo", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected videos from the project"),
 	 G_CALLBACK (brasero_video_disc_delete_activated_cb)},
@@ -407,7 +407,7 @@ brasero_video_disc_not_video_dialog (BraseroVideoDisc *self,
 	primary = g_strdup_printf (_("\"%s\" does not have a suitable type for video projects."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
-			   _("Please only add files with video contents"),
+			   _("Please only add files with video content"),
 			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
diff --git a/src/main.c b/src/main.c
index 7cdd7e6..7de917c 100644
--- a/src/main.c
+++ b/src/main.c
@@ -103,7 +103,7 @@ static const GOptionEntry options [] = {
 	  NULL },
 
 	{ "image", 'i', 0, G_OPTION_ARG_STRING, &iso_uri,
-	 N_("Uri of an image file to burn (autodetected)"),
+	 N_("URI of an image file to burn (autodetected)"),
           N_("PATH TO PLAYLIST") },
 
     	{ "empty", 'e', 0, G_OPTION_ARG_NONE, &empty_project,
@@ -123,7 +123,7 @@ static const GOptionEntry options [] = {
 	  NULL },
 
 	{ "burn-and-remove-project", 'r', 0, G_OPTION_ARG_STRING, &burn_project_uri,
-	  N_("Burn the specified project and REMOVE it.\nThis option is mainly useful for integration use with other applications."),
+	  N_("Burn the specified project and remove it.\nThis option is mainly useful for integration with other applications."),
 	  N_("PATH") },
 
 	{ "transient-for", 'x', 0, G_OPTION_ARG_INT, &parent_window,
@@ -199,9 +199,9 @@ brasero_handle_burn_uri (BraseroApp *app,
 		gchar *string;
 
 		if (error)
-			string = g_strdup_printf (_("An internal error occured (%s)"), error->message);
+			string = g_strdup_printf (_("An internal error occurred (%s)"), error->message);
 		else
-			string = g_strdup (_("An internal error occured"));
+			string = g_strdup (_("An internal error occurred"));
 
 		brasero_app_alert (app,
 				   _("Error while loading the project"),
@@ -225,9 +225,9 @@ brasero_handle_burn_uri (BraseroApp *app,
 		gchar *string;
 
 		if (error)
-			string = g_strdup_printf (_("An internal error occured (%s)"), error->message);
+			string = g_strdup_printf (_("An internal error occurred (%s)"), error->message);
 		else
-			string = g_strdup (_("An internal error occured"));
+			string = g_strdup (_("An internal error occurred"));
 
 		brasero_app_alert (app,
 				   _("Error while loading the project"),
@@ -461,7 +461,7 @@ main (int argc, char **argv)
 	g_option_context_add_group (context, brasero_burn_library_get_option_group ());
 	g_option_context_add_group (context, gst_init_get_option_group ());
 	if (g_option_context_parse (context, &argc, &argv, NULL) == FALSE) {
-		g_print (_("Please type %s --help to see all available options\n"), argv [0]);
+		g_print (_("Please type \"%s --help\" to see all available options\n"), argv [0]);
 		g_option_context_free (context);
 		exit (1);
 	}



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/plugins/cdrkit/burn-wodim.c b/plugins/cdrkit/burn-wodim.c
index 4090da0..edf9c5e 100644
--- a/plugins/cdrkit/burn-wodim.c
+++ b/plugins/cdrkit/burn-wodim.c
@@ -202,13 +202,13 @@ brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 	**/
 
 	/** For these we'd rather have a message saying "cdrecord failed"
 	 *  as an internal error occured says nothing/even less
 	else if (strstr (line, "Bad file descriptor. read error on input file")
 	     ||  strstr (line, "Input buffer error, aborting")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("An internal error occured")));
+						_("An internal error occurred")));
 	}
 
 	**/
@@ -704,7 +704,7 @@ error:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("An internal error occured"));
+		     _("An internal error occurred"));
 
 	return BRASERO_BURN_ERR;
 }
@@ -819,7 +819,7 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 		
@@ -834,7 +834,7 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -1395,7 +1395,7 @@ brasero_wodim_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* add some configure options */
 	immed = brasero_plugin_conf_option_new (GCONF_KEY_IMMEDIATE_FLAG,
-						_("Enable \"-immed\" flag (see wodim manual)"),
+						_("Enable the \"-immed\" flag (see wodim manual)"),
 						BRASERO_PLUGIN_OPTION_BOOL);
 	minbuf = brasero_plugin_conf_option_new (GCONF_KEY_MINBUF_VALUE,
 						 _("Minimum drive buffer fill ratio (in %) (see wodim manual):"),
@@ -202,13 +202,13 @@ brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 
 	/** For these we'd rather have a message saying "cdrecord failed"
-	 *  as an internal error occured says nothing/even less
+	 *  as an internal error occurred says nothing/even less
 	else if (strstr (line, "Bad file descriptor. read error on input file")
 	     ||  strstr (line, "Input buffer error, aborting")) {
diff --git a/plugins/cdrtools/burn-cdrecord.c b/plugins/cdrtools/burn-cdrecord.c
index 15449ad..4876443 100644
--- a/plugins/cdrtools/burn-cdrecord.c
+++ b/plugins/cdrtools/burn-cdrecord.c
@@ -114,13 +114,13 @@ brasero_cdrecord_stderr_read (BraseroProcess *process, const gchar *line)
 						BRASERO_BURN_ERROR_MEDIUM_SPACE,
 						_("Not enough space available on the disc")));
 	}
-	else if (strstr (line ,"cdrecord: A write error occured")
+	else if (strstr (line ,"cdrecord: A write error occurred")
 	     ||  strstr (line, "Could not write Lead-in")
 	     ||  strstr (line, "Cannot fixate disk")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 	}
 	else if (strstr (line, "DMA speed too slow") != NULL) {
 		brasero_job_error (BRASERO_JOB (process),
@@ -203,13 +203,13 @@ brasero_cdrecord_stderr_read (BraseroProcess *process, const gchar *line)
 	**/
 
 	/** For these we'd rather have a message saying "cdrecord failed"
 	 *  as an internal error occured says nothing/even less
 	else if (strstr (line, "Bad file descriptor. read error on input file")
 	     ||  strstr (line, "Input buffer error, aborting")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("An internal error occured")));
+						_("An internal error occurred")));
 	}
 
 	**/
@@ -687,7 +687,7 @@ error:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("An internal error occured (%s)"), 
+		     _("An internal error occurred (%s)"), 
 		     g_strerror (errsv));
 
 	return BRASERO_BURN_ERR;
@@ -804,7 +804,7 @@ brasero_cdrecord_set_argv_record (BraseroCDRecord *cdrecord,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 		
@@ -819,7 +819,7 @@ brasero_cdrecord_set_argv_record (BraseroCDRecord *cdrecord,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -1384,10 +1384,10 @@ brasero_cdrecord_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* add some configure options */
 	immed = brasero_plugin_conf_option_new (GCONF_KEY_IMMEDIATE_FLAG,
-						_("Enable \"-immed\" flag (see cdrecord manual)"),
+						_("Enable the \"-immed\" flag (see cdrecord manual)"),
 						BRASERO_PLUGIN_OPTION_BOOL);
 	minbuf = brasero_plugin_conf_option_new (GCONF_KEY_MINBUF_VALUE,
-						 _("Minimum drive buffer fill ratio (in %%)(see cdrecord manual):"),
+						 _("Minimum drive buffer fill ratio (in %%) (see cdrecord manual):"),
 						 BRASERO_PLUGIN_OPTION_INT);
 	brasero_plugin_conf_option_int_set_range (minbuf, 25, 95);
 
@@ -203,13 +203,13 @@ brasero_cdrecord_stderr_read (BraseroProcess *process, const gchar *line)
 
 	/** For these we'd rather have a message saying "cdrecord failed"
-	 *  as an internal error occured says nothing/even less
+	 *  as an internal error occurred says nothing/even less
 	else if (strstr (line, "Bad file descriptor. read error on input file")
 	     ||  strstr (line, "Input buffer error, aborting")) {